#
# spec file for package libQuotient
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 0_6
%define sonum 0.6
%bcond_with e2ee
Name:           libQuotient
Version:        0.6.11
Release:        bp154.1.111
Summary:        Library for Qt Matrix Clients
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/quotient-im/libQuotient
Source0:        https://github.com/quotient-im/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.9
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
%if %{with e2ee}
BuildRequires:  cmake(Olm)
%endif

%description
Library for Qt-based Matrix chat clients. It is required by
Quaternion.

%package -n %{name}%{soversion}
Summary:        Library for Qt Matrix Clients
Group:          System/Libraries

%description -n %{name}%{soversion}
Library for Qt-based Matrix chat clients. It is required by
Quaternion.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soversion} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%cmake \
    -DQuotient_INSTALL_TESTS=OFF \
%if %{with e2ee}
    -DQuotient_ENABLE_E2EE=ON
%else
    -DQuotient_ENABLE_E2EE=OFF
%endif

%cmake_build

%install
%cmake_install
# Not useful
rm -r %{buildroot}%{_datadir}/ndk-modules/

%post  -n %{name}%{soversion} -p /sbin/ldconfig
%postun -n %{name}%{soversion} -p /sbin/ldconfig

%files -n %{name}%{soversion}
%doc README.md
%license COPYING
%{_libdir}/libQuotient.so.%{version}
%{_libdir}/libQuotient.so.%{sonum}

%files devel
%doc README.md
%license COPYING
%{_libdir}/pkgconfig/Quotient.pc
%{_libdir}/libQuotient.so
%{_libdir}/cmake/Quotient/
%{_includedir}/Quotient/

%changelog
* Thu Oct  7 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.11:
  * Just after 0.6.10 was out another nasty bug has been discovered,
    preventing from proper usage of URLs with an unescaped double-hash (##),
    which may come when a matrix.to URL is generated for a bridged IRC channel
    (and it even got a very nice number #512). Aside from this fix,
    quotest will not return with success code 0 any more if it failed to
    even start testing for some reason (#496).
* Sun Oct  3 2021 Dead Mozay <dead-mozay@opensuse.org>
- Update to versiosn 0.6.10:
  * Yet another maintenance release of the stable branch, fixing an
    issue (#510) with invites not showing up in some cases
    (especially on less active/smaller accounts).
* Sun Sep 12 2021 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.6.9:
  * Here's one more stable branch release of libQuotient,
    fixing a rare assertion failure due to uninitialised
    read marker when new events arrive and all history
    is already loaded.
* Tue Aug 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.8:
  * Retain the current room member avatar when renaming the user
    for the room.
  * When displaying the room, notification/highlight counters are
    no more reset. This never really worked, with the notification
    and highlight counts jumping to zero and then back to the
    original value if the timeline hasn't been completely read;
    now that read receipts are correctly sent, the counters
    can be left to the homeserver to update
    (while E2EE is not around).
  * Fix the missing percent encoding in User::fetchProfile(),
    leading to problems around historical userids that still
    have slashes.
  * CS API files have been regenerated from the new matrix-doc
    after revamping the layout and tooling; the library API didn't
    change, but doc-comments are now in Markdown rather than
    ReStructured Text.
  * Update GTAD configuration to version 0.8 of the tool.
  * Fix potential linking errors around quotient_common.h.
* Sun Jul 18 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Updae to version 0.6.7:
  * One more maintenance release at the stable branch, fixing
    gh#quotient-im/libQuotient#471 that affects NeoChat - thanks
    to @ognarb for pinpointing and suggesting a fix to it.
- Mention soversion in %%files
- Simplify %%files
- Use full tarball name
- Don't install quotest and ndk-modules/Android.mk
* Thu Mar 18 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.6:
  * Another update on the stable branch, to address #456
    (possible crash on some malformed user ids).
* Wed Feb 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.5:
  * Fix rich replies handling.
  * Support abbreviated aka Reddit-style type specifiers in
    Matrix URIs (e.g., matrix:r/quotient:matrix.org)
* Sat Jan 16 2021 Luca Beltrame <lbeltrame@kde.org>
- Actually disable e2ee
* Fri Jan 15 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.4:
  * Several fixes around homeserver resolution.
* Sun Jan  3 2021 Luca Beltrame <lbeltrame@kde.org>
- Add a build conditional for E2EE and disable it by default, as
  applications using libQuotient with E2EE enabled have
  stability issues and memory leaks
- Run spec-cleaner
* Tue Dec 29 2020 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.6.3:
  * (#412 with an additional fix in e7c9ca9) Take profile data from
    the previous user state for users who already left
  * (693241d) Fix defunct network requests stalling the request queue
  * (e81117f, 6e8be18) Minor performance improvements on loading
    rooms and accounts involving many users (0.7 will have more work
    on handling that)
  * (2340f3d) Power level events are properly redacted now locally
  * (ff2cb9f) Work around lack of native Qt support for request
    bodies in DELETE requests
  * (97b0bec) Fix a few cases of insufficient escaping in
    Quotient::Uri (thanks to nephele for reporting)
  * (#421) Fix incorrect processing when a network request
    (especially for .well-known) returns 404 with non-empty body
    that is not JSON (which is quite usual when a .well-known
    record is missing)
  * (66972c8) Room tags that start with . (fullstop) are no more
    considered correct and will get u. in front of them.
  * Many thanks for all the help in testing and contributing!
* Sat Oct 24 2020 dead-mozay@opensuse.org
- Update to version 0.6.2:
  * More stringent serverpart checks in user ids.
  * Uri::toUrl() now returns an actually working matrix.to link.
  * The biggest change in this release is a rewrite of the code
    maintaining user profiles (generic and per-room).
    The new code is simpler, faster and occupies less memory -
    a hat-trick of optimisation. The improvement is most noticeable
    when opening bigger rooms with many users (such as Matrix HQ).
  * Trying to set displayname or avatar URL to an empty value with
    Synapse homeservers led to an obscure error;
    now it works as it should.
  * Another noticeable change is that the library should be more
    robust against gateway/CDN/proxy errors that sometimes bring
    unexpected responses (e.g. an HTML payload when JSON is expected).
  * Quotest: added a test for changing the user display name
  * User::bridged() and User::rawName() has long been useless,
    as Matrix stopped using bridge postfixes - they are deprecated now.
  * Smaller optimisations, cleanup and documentation updates, as usual.
* Fri Jul 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.6.0 stable
* Tue Jun  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.6-beta1
  * actually build against the packaged libQtOml instead of the
    intree version
* Sat Feb 22 2020 dead_mozay@opensuse.org
- Update to version 0.6.0:
  * Fix build on big-endian systems
  * Use parsed RoomPowerLevelsEvent in room upgrading
  * Add powerLevelForState()
  * Mark methods as const.
* Fri May 24 2019 ecsos@opensuse.org
- Update to 0.5.2
  - (#323) Direct chats are no more unmarked when logging in or
    after clearing the cache.
  - 0.5.x releases keep the previous library name, libQMatrixClient
- Upstream renamed library to libQuotient, so this package
  libqmatrixclient also renamed to libQuotient.
* Thu Apr 18 2019 ecsos@opensuse.org
- Update to 0.5.1.2
  - (#316) Expired tokens no more bring IncorrectRequestError
    instead of ContentAccessError; consequently,
    Connection::logout() ignores ContentAccessErrors so expired
    tokens don't leave the library in a "can't go-in, can't go out"
    state.
  - Jobs abandoned due to Connection being deleted no more cause
    crashes.
* Sat Apr  6 2019 ecsos@opensuse.org
- Update to 0.5.1.1
  This release fixes a bug that makes 0.5.1 not being "new enough"
  for Quaternion 0.0.9.4, and another bug that made user showing up
  multiple times in the user list of Quaternion after renaming.
  Otherwise it's the same as version 0.5.1.
* Fri Apr  5 2019 ecsos@opensuse.org
- Update to 0.5.1
  - Fix (#303): linkification doesn't break on peculiar links.
  - Fix (#310 and 27c2989): quirks in rendering room display names
    have been ironed out.
  - Fix: Tighter validations of URLs coming with file events
    (too relaxed validations were causing the library to
    assert-crash on, e.g., encrypted attachments).
  - Enhancement (#305): rooms created as direct chats are now
    automatically marked as m.direct for invited as well as
    inviting users.
  - Enhancement (#306): Room::canSwitchVersions() returns false on
    rooms already upgraded (you still can disregard and call
    Room::switchVersion() but you better think twice
  - see matrix-org/matrix-doc#1937).
  - Enhancement: Room::postFile() now first starts file upload and
    then places a pending event (neatly packed with file transfer
    information), rather than the other way around. Unless you do
    weird things with the library's API, you shouldn't notice.
  - Enhancement: LRO/RLO Unicode markers are now stripped from
    display names, to curtail abuse of those.
  - Feature: Connection::domain() to save client authors from
    taking the domain from user MXID.
* Wed Apr  3 2019 ecsos@opensuse.org
- Update to 0.5.0.2
  * Another bugfix release in 0.5.x branch, fixing issues with
    sending read receipts and redactions in v3 rooms (#300).
- Changes from 0.5.0.1
  * This version fixes too stringent checks in debug builds that
    led to assertion crashes upon encounter with upgraded rooms.
- Changes from 0.5
  As usual for 0.x versions, 0.5 breaks API compatibility with
  previous versions; 0.4-compatible clients may or may not need
  changes in order to compile with version 0.5. As usual, see diffs
  in header files to track the changes and update the client code
  accordingly; these release notes highlight most prominent API
  changes.
  Micro-versions in 0.5.y will maintain the API and ABI.
  Version 0.6 will break either API or ABI or both.
  Over 200 commits. So see for changelog
  https://github.com/QMatrixClient/libqmatrixclient/commits/0.5.0
* Sun Jan 13 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.4.2.1:
  * No more treat fake state events (that don't have
    state_key, even if they have state-related type, e.g., m.room.topic)
    as state events, turning them into unknown events instead.
* Sun Dec 16 2018 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1
  * Fix pending events (aka local echo) not being cleaned up
    properly
  * Fix rooms not being correctly sorted according to their
    position under tag if using Connection::roomsByTags()
  * Fix incorrect SOVERSION
* Fri Nov  9 2018 ecsos@opensuse.org
- Remove soname from devel.
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Edit RPM groups.
* Tue Oct 16 2018 ecsos@opensuse.org
- update to 0.4.0
  So many changes and no propoer changelog from upstream.
  See changes here:
  https://github.com/QMatrixClient/libqmatrixclient/compare/v0.3.0.2...v0.4.0
* Mon Aug 20 2018 ecsos@opensuse.org
- update to 0.3.0.2
  So many changes and no proper changelog from upstream.
  See changes here:
  https://github.com/QMatrixClient/libqmatrixclient/compare/v0.2.1...v0.3.0.2
* Wed May  2 2018 ecsos@opensuse.org
- update to 0.2.1
  - Fixed an occasional crash due to dangling callbacks in avatar
    fetching code
  - Fixed unreliable network error handling leading to sync loop
    getting "unlooped" when server is temporarily unavailable
  - Fixed a regression leading to bridge postfixes not being
    removed from user display names
  - Fixed a regression manifesting in dysfunctional user name
    disambiguation
  - Added User::rawName() to get a user name together with its
    bridge postfix
  - Bridge names are now used as the first line of disambiguation,
    with user ids being the next (and ultimate) fallback.
- remove service file
* Thu Apr 12 2018 agraul@suse.com
- remove remove_unwanted_cmake_installations.patch
  * upstream remove EXPORT_ANDROID_MK from install targets
- use service to download sources from github
* Tue Apr  3 2018 agraul@suse.com
- add remove_unwanted_cmake_installations.patch
  * this patch removes cmake install targets that are not
    targeted at linux
- cleanup spec file
* Mon Apr  2 2018 agraul@suse.com
- update to 0.2rc
- fix build
* Mon Jan  1 2018 agraul@suse.com
- add cmake_install_target.patch
* Mon Jan  1 2018 agraul@suse.com
- update to 0.2-q0.0.5
* Fri Nov 10 2017 agraul@suse.com
- inital package
